/**
 * @file libcomprex/file_api.h File input/output API
 * 
 * $Id: file_api.h,v 1.4 2001/12/31 09:25:20 chipx86 Exp $
 *
 * @Copyright (C) 2001-2002 The GNUpdate Project.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#ifndef _LIBCOMPREX_FILE_API_H_
#define _LIBCOMPREX_FILE_API_H_

#include <comprex.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Opens a file from a local or remote filesystem, or in an archive.
 *
 * @param path The path to the file.
 * @param mode The access mode.
 *
 * @return The file, if it exists. NULL otherwise.
 */
CxFile *cxOpenFile(const char *path, CxAccessMode mode);

/**
 * Closes a file.
 * 
 * The CxFile structure will be deleted after this is called.
 * 
 * @param file The file to close.
 */
void cxCloseFile(CxFile *file);

/**
 * Reads data from a file.
 *
 * @param ptr   The buffer which will store the data.
 * @param size  The size of an element of data.
 * @param nmemb The number of elements of size @size to receive.
 * @param file  The file to read from.
 *
 * @return The number of elements read, or 0 on error or end of file.
 */
size_t cxRead(void *ptr, size_t size, size_t nmemb, CxFile *file);

/**
 * Writes data to a file.
 *
 * @param ptr   The data to write.
 * @param size  The size of an element of data.
 * @param nmemb The number of elements of size @size to receive.
 * @param file  The file to write to.
 *
 * @return The number of elements written, or 0 on error.
 */
size_t cxWrite(const void *ptr, size_t size, size_t nmemb, CxFile *file);

/**
 * Clears the error flag and end-of-file indicator.
 *
 * @param file The file.
 */
void cxClearErr(CxFile *file);

/**
 * Tests the end-of-file indicator.
 *
 * @param file The file.
 *
 * @return 1 if the end-of-file indicator is set; 0 otherwise.
 */
int cxEof(CxFile *file);

/**
 * Tests the error indicator of the file.
 *
 * @param file The file.
 *
 * @return The error if set, or 0 on no error.
 */
int cxError(CxFile *file);

/**
 * Returns a string representation of the error.
 *
 * @param file   The associated file.
 * @param errnum The error number.
 *
 * @return The string representation of the error.
 */
const char *cxStrError(CxFile *file, int errnum);

#ifdef __cplusplus
}
#endif

#endif /* _LIBCOMPREX_FILE_API_H_ */

